clc, close all, clear all

%% Notes
% This is an example scirpt to show how to make simple caluclations of
% plunge-pool erosion folliowing the theory in Scheingross and Lamb (in
% review).  You are responsible for inspecting the code to make sure it
% will work for your purposes.  Please e-mail errors or bugs to Joel
% Scheingross at jscheingross .a.t. gmail dot com.

%% Simple scenario
% This is a simple case if you want to calculate an erosion rate
% for a given plunge pool

% Define your inputs (here we're using generic values for the Fox Creek reference site):
Qs = 0.0119; % sediment flux (m3/s)
r_pool = 3; %pool radius (m)
Q = 7.27; %water discharge (m3/s)
h_br = 2; %pool depth to bedrock (m)
H_drop = 10.38; %waterfall drop height (m)
W = 4.1; %channel width upstream of the waterfall (m)
D = 0.024; %Grain size (m)
h_brink = 0.36; %flow depth at the waterfall brink (m)
sigmaT = 7e6; %rock tensile strength (Pa)

% Run the script, it outputs vertical and lateral erosion rates in units mm/yr
% Note, these values are instaneous erosion rates, so if you want to
% include an intermittancy factor, you'll need to multiply the outputs by
% whichever intermittancy factor you choose.
[E_vert_avg_mm_yr, E_lat_avg_mm_yr] = ...
    pool_erosion_simple_fct(Qs, r_pool, Q, h_br, H_drop, W, D, h_brink, sigmaT);

%% Predict vertical and lateral erosion rates as a function of water discharge (Fig. 5e)
% We'll also hold the ratio of sediment supply to sediment transport
% capacity constant

% Set some constants we'll need
R = 1.65; %normalized submerged sediment density (non-dimensional)
g = 9.81; %gravitational acceleration
tau_star_c = 0.045; %critical Shields stress
If = 0.01; %define a 1% intermittancy factor
S = 0.05; %Fox Creek reach-averaged slope upstream of the waterfalls

% Set a range of discharges
Qw_vary = logspace(-1,2.2,250); %vary discharge over some range
q_vary = Qw_vary./W; %water discharge per unit width (m2/s)

for i = 1:length(Qw_vary)
    q_vary = Qw_vary(i)./W; %water discharge per unit width (m2/s)
    
    % We'll have to calculate h_brink for each discharge value, we do this
    % assuming steady, uniform flow, using an established friction
    % factor (see Section 2.6)
    h_normal = ((Qw_vary(i).*(3.*D).^(1/6))./(8.1.*W.*sqrt(g.*S))).^(3/5);
    
    u_vary = Qw_vary(i)./(h_normal.*W); %normal flow velocity upstream of the waterfall
    Fr_n_vary = u_vary./sqrt(g.*h_normal); % Fr upstream of the waterfall
    if Fr_n_vary > 1;
        Fr_lip_vary = ((0.4+Fr_n_vary.^2)./Fr_n_vary.^2).^(3/2).*Fr_n_vary; %Fr at the waterfall lip for supercritical flow
    else
        Fr_lip_vary = (1.4./Fr_n_vary.^(2/3)).^(3/2).*Fr_n_vary; %Fr at the waterfall lip for subcritical flow
    end
    h_brink_vary = (q_vary./(sqrt(g).*Fr_lip_vary)).^(2/3); %flow depth at the waterfall brink
    
    % Hold Qs/Qsc_river constant
    tau_star_vary = h_normal.*S./(R.*D);
    Qsc_river_vary(i) = 5.7.*W.*sqrt(R.*g.*D.^3).*(tau_star_vary-tau_star_c).^(1.5);
    Qs_vary(i) = 0.5.*Qsc_river_vary(i);
    
    if Qs_vary(i) == 0 % get rid of all cases below the threshold of motion
        Evert_vary_Q(i) = 0;
        Elat_vary_Q(i) = 0;
    else % run the model for cases when sediment supply is non-zero
        [Evert_vary_Q(i), Elat_vary_Q(i)] = ...
            pool_erosion_simple_fct(Qs_vary(i), r_pool, Qw_vary(i), h_br, H_drop, ...
            W, D, h_brink_vary, sigmaT);
    end
end

% Note: The lines in the figure may show some numerical instablities, you
% can fix this by opening "pool_erosion_simple_fct.m" and increasing
% "dr_spacing" and "dz_spacing")

figure
loglog(Qw_vary, Evert_vary_Q.*If, 'k-')
hold on
plot(Qw_vary, Elat_vary_Q.*If, 'k-', 'color', [0.6 0.6 0.6])
xlabel('Water discharge (m^3/s)')
ylabel('Erosion rate (mm/yr)')
legend('E_v_e_r_t', 'E_l_a_t')
title('Q_s / Q_s_c_ _r_i_v_e_r = 0.5')
ylim([1e-3 1e3])
xlim([min(Qw_vary) max(Qw_vary)])

